<?php

namespace App\Http\Controllers;
use App\Mail\PasswordRecoveryMail;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class UserController extends Controller
{
    // Récupérer tous les utilisateurs (GET /users)
    public function index()
    {
        return response()->json(User::with('jobListings','applications','profile')->get());
    }

    public function getAtuh()
    {
        return response()->json(User::with('profile')->where('id',Auth::id())->first());
    }

    // Récupérer un utilisateur par son ID (GET /users/{id})
    public function show($id)
    {
        $user = User::find($id);
        if (!$user) {
            return response()->json(['message' => 'Utilisateur non trouvé'], 404);
        }
        return response()->json($user);
    }

    // Créer un nouvel utilisateur (POST /users)
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|unique:users,email',
            'password' => 'required|string|min:6',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
        ]);

        return response()->json($user, 201);
    }

    // Mettre à jour un utilisateur (PUT/PATCH /users/{id})
    public function update(Request $request)
    {
        $user = $request->user();
    
        $validator = Validator::make($request->all(), [
            'name' => 'sometimes|required|string|max:255',
            'email' => 'sometimes|required|string|email|max:255|unique:users,email,' . $user->id,
            'password' => 'sometimes|required|string|min:8|confirmed',
        ]);
    
        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }
    
        $validated = $validator->validated();
        
        // Vérifiez si le mot de passe est défini et cryptez-le
        if (isset($validated['password'])) {
            $validated['password'] = bcrypt($validated['password']);
        }
    
        // Met à jour uniquement les champs fournis
        $user->update(array_filter($validated)); 
    
        return response()->json(["success"=>"success"],200);
    }

    // Supprimer un utilisateur (DELETE /users/{id})
    public function destroy($id)
    {
        $user = User::find($id);
        if (!$user) {
            return response()->json(['message' => 'Utilisateur non trouvé'], 404);
        }
        
        $user->delete();
        return response()->json(['message' => 'Utilisateur supprimé avec succès'], 200);
    }

    // Mot de Passe Oublié
    public function recoverPassword(Request $request) {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email|string|exists:users,email',
        ]);
        
        if ($validator->fails()) {
            return response()->json(['Erreur' => 'L\'email n\'existe pas.'], 404);
        }
    
        // Obtenir l'utilisateur et générer un mot de passe aléatoire
        $user = User::where('email', $request->email)->first();
        $temporaryPassword = Str::random(8); // Générer un mot de passe aléatoire
    
        // Mettre à jour le mot de passe de l'utilisateur
        $user->password = bcrypt($temporaryPassword);
        $user->save();
    
        // Envoyer un email avec le mot de passe temporaire
        Mail::to($user->email)->send(new PasswordRecoveryMail($temporaryPassword));
    
        return response()->json(['status' => 'Un email avec un mot de passe temporaire a été envoyé.'], 200);
    }
}